==> hledger-1.40-25-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.40
visibility:           public
id:                   hledger-1.40-JEWd589Yhb8KLLR8mkUoRf
key:                  hledger-1.40-JEWd589Yhb8KLLR8mkUoRf
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  82a6fcbf5234f31f758b2e18359a8efa
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Aregister Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-1.40
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-1.40
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-1.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.40-JEWd589Yhb8KLLR8mkUoRf
depends:
    Decimal-0.5.2-7Hvvqy46Kk3TfHnEOW5Ky
    Diff-0.4.1-HOGfEyxGmCUAz64jdnP9fa
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD
    ansi-terminal-1.0.2-8A8xJnPl6su1eTYW5nsKkX base-4.17.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    directory-1.3.7.1 extra-1.7.16-Isi0tZEk9Ra6WEOKtqTjmT
    filepath-1.4.2.2 githash-0.1.6.3-38q1M2stlGwWMpB1FHVeO
    hashable-1.4.4.0-GlxcJ9XR4pRDbsSt4txSan haskeline-0.8.2
    hledger-lib-1.40-1nK9ZSVs8ZFCBES8EQwh1I
    lucid-2.11.20250303-6laUXMr44WF2xh1sdkWjxR
    math-functions-0.3.4.4-DBORphe8j96tvXFlWQxba
    megaparsec-9.7.0-3djLYUlnjlAJjkWgXBHMlu
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    process-1.6.18.0 regex-tdfa-1.3.2.4-GBJv531HDPIL53gZ8aHH9h
    safe-0.3.21-DqCLuIhxH5d2cQjqD83Qv7
    shakespeare-2.1.4-IRdfqQj2xVhLuYkwxupaYi
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.5-4qs3JVCwJf4LGOgKldJdL2
    temporary-1.3-EG3p5EUtjekFmwlm9f2IPf terminfo-0.4.1.5 text-2.0.2
    text-ansi-0.3.0.1-5bnwyac4gZM9eTMOZv4C1r time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    utility-ht-0.0.17.2-Fq03W0oKRWoA7yUrufBvzL
    wizards-1.0.3-KdOLRFMRRl1t6euiwGd

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.40-26-x86_64.pkg.tar.zst: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.40
visibility:           public
id:                   hledger-1.40-HWPB6Iz3mZQI1fyIBaCt0H
key:                  hledger-1.40-HWPB6Iz3mZQI1fyIBaCt0H
license:              GPL-3.0-only
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  5883d207f1d7f0d19122ca1dcfdd2b42
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anon Hledger.Cli.CliOptions
    Hledger.Cli.Commands Hledger.Cli.Commands.Accounts
    Hledger.Cli.Commands.Activity Hledger.Cli.Commands.Add
    Hledger.Cli.Commands.Aregister Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hledger-1.40
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hledger-1.40
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hledger-1.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.40-HWPB6Iz3mZQI1fyIBaCt0H
depends:
    Decimal-0.5.2-1AlZgSdvq2o8KDbLErfGXD
    Diff-0.4.1-6W9agSIlIY8G6HEwmmNbRz
    aeson-2.1.2.1-8PRfz0Kg6mwK2TOn7o5BkY
    ansi-terminal-1.0.2-EWRmoRkCD6N8oQC0Fs2AaT base-4.17.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-KMcxPO0UszDDPT8hI73uO5
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    directory-1.3.7.1 extra-1.7.16-RhNJqbxY8a77mG7dDYp5d
    filepath-1.4.2.2 githash-0.1.6.3-855EcWGJQZZ9z1WOa6ASAK
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM haskeline-0.8.2
    hledger-lib-1.40-L2GELDDsVeU85vc71vfQUd
    lucid-2.11.20250303-6KubpGnHr6Q5pvMkFcFE6k
    math-functions-0.3.4.4-HMyMV6wX9bMKq3TBTgaSbZ
    megaparsec-9.7.0-JdLotAX9gxvJ8pGS1qwpyC
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt mtl-2.2.2
    process-1.6.18.0 regex-tdfa-1.3.2.4-JO7YM3YKT70AKRnIA3I8ji
    safe-0.3.21-HL4mjR4LPAfAu0GeFkJLe6
    shakespeare-2.1.4-HeiyZnsV2nR76DyoJc0Xci
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    tabular-0.2.2.8-GPlaI3PukxDKI4c6j3m1vm
    tasty-1.5-DeV5iqdANbXL7LhyTuIGej
    temporary-1.3-6YbEjLKDNjc6IO1VlPHH38 terminfo-0.4.1.5 text-2.0.2
    text-ansi-0.3.0.1-4xgkDlJpdBKAQIgzXsywIF time-1.12.2
    timeit-2.0-GSLifhpRLI5Gr54jWRx5t0 transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    utility-ht-0.0.17.2-IuLbdMnHL0oGZhJaFz4euy
    wizards-1.0.3-KdOLRFMRRl1t6euiwGd

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
